/*  This file is part of the KDE project
    SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>

    SPDX-License-Identifier: LGPL-2.0-or-later
*/

#pragma once

#include "mailimporter_export.h"

/* Classes which are exported only for unit tests */
#ifdef BUILD_TESTING
#ifndef MAILIMPORTER_TESTS_EXPORT
#define MAILIMPORTER_TESTS_EXPORT MAILIMPORTER_EXPORT
#endif
#else /* not compiling tests */
#define MAILIMPORTER_TESTS_EXPORT
#endif

